@@ -1,12 +1,13 @@
 package ZHOUYI;
-use utf8;
+
 require Exporter;
+use utf8;
 use strict;
 use warnings;
 
-our @ISA    = qw(Exporter);
-our @EXPORT = qw(ZhouyiEx ZYindex outGua sixyao outtuan outxiang maixyao maixiang);
-=encoding utf8
+our @ISA     = qw(Exporter);
+our @EXPORT  = qw(ZhouyiEx ZYindex outGua sixyao outtuan outxiang);
+
 =head1 NAME
 
 ZHOUYI - The ZHOUYI is module interpreter and outer the Chinese ancient
@@ -14,14 +15,18 @@ philosophy of The Book of Change(易经);
 
 =head1 VERSION
 
-Version 0.011
+Version 0.01
 
 =cut
 
-our $VERSION = '0.011';
+our $VERSION = '0.03';
+
 
 =head1 SYNOPSIS
 
+Quick summary of what the module does.
+
+Perhaps a little code snippet.
 
     use ZHOUYI;
 
@@ -31,71 +36,13 @@ our $VERSION = '0.011';
 
 =head1 EXPORT
 
-ZhouyiEx ZYindex outGua sixyao outtuan outxiang maixyao maixiang
-
 A list of functions that can be exported.  You can delete this section
 if you don't export anything, such as for a purely object-oriented module.
 
-
 =head1 SUBROUTINES/METHODS
 
-=head2 ZHouYiEx
-
-return YI info
-
-=head2 ZYindex
-
-return YI index of 1~81 gua.
-
-=head2 outGua outtuan sixyao outxiang
-
-return special  gua's info of 卦体，爻,彖传，象辞.
-
-=head2 maixyao maixiang
-
-return special yao's info of 爻,象辞, and the it's array. 
-
 =cut
 
-my ( $ZYdb, @ZYdb );
-@ZYdb = <DATA>;
-$ZYdb .= $_ for @ZYdb;
-
-sub Bindex {
-    my ( @yigua, %yi, %zy, @bagua, @bagua1,@bgindex,@num);
-
-    @bagua  = qw(kun zhen kan dui gen li xun qian);
-    @bagua1 = qw(di lei shui ze shan huo feng tian);
-    @bgindex =
-      qw(tian_tian tian_ze tian_huo tian_lei tian_feng tian_shui tian_shan tian_di ze_tian ze_ze ze_huo ze_lei ze_feng ze_shui ze_shan ze_di huo_tian huo_ze huo_huo huo_lei huo_feng huo_shui huo_shan huo_di lei_tian lei_ze lei_huo lei_lei lei_feng lei_shui lei_shan lei_di feng_tian feng_ze feng_huo feng_lei feng_feng feng_shui feng_shan feng_di shui_tian shui_ze shui_huo shui_lei shui_feng shui_shui shui_shan shui_di shan_tian shan_ze shan_huo shan_lei shan_feng shan_shui shan_shan shan_di di_tian di_ze di_huo di_lei di_feng di_shui di_shan di_di);
-    @num =
-      qw(1 10 13 25 44 6 33 12 43 58  49 17 28 47 31 45 14 38 30 21 50 64 56 35 34 54 55 51 32 40 62 16 9 61 37 42 57 59 53 20 5 60 63 3 48 29 39 8 26 41 21 27 18 4 52 23 11 19 36 24 46 7 15 2);
-
-    @zy{@bgindex} = @num;
-    for ( 0 .. 63 ) {
-
-        my $zindexs = sprintf( "%lo", $_ );
-        push @yigua, $zindexs;
-    }
-
-    for (@yigua) {
-
-        if (/^\d$/) {
-
-            #print $_,"\n";
-            $yi{$_} = $bagua1[0] . "_" . $bagua1[$_];
-
-        }
-        else {
-            my ( $q, $k ) = split //, $_;
-            $yi{$_} = $bagua1[$q] . "_" . $bagua1[$k];
-        }
-
-    }
-
-    return ( \%zy, \%yi );
-}
-
 sub ZYindex {
     my ( $wgua, $ngua ) = @_;
     $wgua %= 8;
@@ -115,23 +62,27 @@ sub ZYindex {
 
 sub ZhouyiEx {
     my ( @line, $msg );
-    my $n = shift;
-    @line = split /^\s+$/sm, $ZYdb;
+    my  $n = shift;
+    {
+        local $/ = "";
+        for (<DATA>) {
+            @line = split /^\s+$/sm;
+        }
+    }
     my $i;
     for (@line) {
         $i++;
         $msg .= "$_\n" if $i == 2 * $n;
         $msg .= "$_\n" if $i == 2 * $n + 1;
     }
-
     return $msg;
 
 }
 
 sub outGua {
-    my $msg = shift;
+    my $msg     = shift;
     my @guatext = split /\n/sm, $msg;
-    my $omsg .= $guatext[1] . "\n\n" . $guatext[4] . "\n\n";
+    my $omsg.=$guatext[1]."\n\n".$guatext[4]."\n\n";
     return $omsg;
 }
 
@@ -139,37 +90,25 @@ sub sixyao {
     my $msg = shift;
     my @guatext = split /\n/sm, $msg;
     my $omsg;
-    $omsg .= outGua($msg);
+    $omsg .=outGua($msg);
     for (@guatext) {
         next if /^$/;
-        next unless /^(初|六|九|上|用).：/;
-        $omsg .= $_ . "\n";
+        next unless  /^(初|六|九|上|用).：/;
+        $omsg .= $_."\n";
     }
     return $omsg;
 }
 
-sub maixyao {
-    my ( $msg, $yao ) = @_;
-    my @guatext = split /\n/sm, $msg;
-    my @yaoci;
-    for (@guatext) {
-        next if /^$/;
-        next unless /^(初|六|九|上|用).：/;
-        push @yaoci, $_;
-    }
-    return ( $yaoci[$yao], \@yaoci );
-}
-
 sub outtuan {
 
     my $msg = shift;
     my @guatext = split /\n/sm, $msg;
     my $omsg;
-    $omsg .= outGua($msg);
+    $omsg .=outGua($msg);
     for (@guatext) {
         next if /^$/;
         next unless /《彖》/;
-        $omsg .= $_ . "\n";
+        $omsg .= $_."\n";
     }
     return $omsg;
 
@@ -179,31 +118,18 @@ sub outxiang {
     my $msg = shift;
     my @guatext = split /\n/sm, $msg;
     my $omsg;
-    $omsg .= outGua($msg);
+    $omsg .=outGua($msg);
     for (@guatext) {
         next if /^$/;
         next unless /《象》/;
-        $omsg .= $_ . "\n";
+        $omsg .= $_."\n";
     }
     return $omsg;
 
 }
-
-sub maixiang {
-    my ( $msg, $yao ) = @_;
-    my @guatext = split /\n/sm, $msg;
-    my @yaoci;
-    for (@guatext) {
-        next if /^$/;
-        next unless /《象》/;
-        push @yaoci, $_;
-    }
-    return ( $yaoci[$yao+1], \@yaoci );
-}
-
 =head1 AUTHOR
 
-orange, C<< <bollwarm at ijz.me> >>
+orange, C<< <linzhe at ijz.me> >>
 
 =head1 BUGS
 
@@ -251,12 +177,12 @@ L<http://search.cpan.org/dist/ZHOUYI/>
 
 Copyright 2016 orange.
 
-This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
+This program is free software; you can redistribute it and/or modify it
+under the terms of the the Artistic License (2.0). 
 
 =cut
 
-1;
-
+1; 
 # End of ZHOUYI
 
 __DATA__
@@ -273,14 +199,7 @@ __DATA__
 上九：亢龍有悔。
 用九：見群龍無首，吉。
 《彖》曰：大哉乾元，萬物資始，乃統天。云行雨施，品物流形。大明始終，六位時成，時乘六龍以御天。乾道變化，各正性命，保合大和，乃利貞。首出庶物，萬國咸寧。
-《象》曰：天行健，君子以自強不息。
-《象》曰：潛龍勿用，陽在下也。
-《象》曰：見龍在田，德施普也。
-《象》曰：終日乾乾，反復道也。
-《象》曰：或躍在淵，進無咎也。
-《象》曰：飛龍在天，大人造也。
-《象》曰：亢龍有悔，盈不可久也。
-《象》曰：用九，天德不可為首也。
+《象》曰：天行健，君子以自強不息。潛龍勿用，陽在下也。見龍在田，德施普也。終日乾乾，反復道也。或躍在淵，進無咎也。飛龍在天，大人造也。亢龍有悔，盈不可久也。用九，天德不可為首也。
 《文言》曰：「元者，善之長也。亨者，嘉之會也。利者，義之和也。貞者，事之干也。君子體仁足以長人。嘉會足以合禮。利物足以和義。貞固足以干事。君子行此四者，故曰『乾，元亨利貞。』」
 初九曰「潛龍勿用」，何謂也？
 子曰：「龍德而隱者也。不易乎世，不成乎名，遯世而無悶，不見是而無悶。樂則行之，憂則違之，確乎其不可拔，乾龍也。」
